@@ -79,10 +79,10 @@ static int ajpv12_sendnbytes(ajp12_endpoint_t * p,
 static int ajpv12_flush(ajp12_endpoint_t * p);
 
 static int ajpv12_handle_response(ajp12_endpoint_t * p,
-                                  jk_ws_service_t *s, jk_logger_t *l);
+                                  jk_ws_service_t *s, jk_log_context_t *l);
 
 static int ajpv12_handle_request(ajp12_endpoint_t * p,
-                                 jk_ws_service_t *s, jk_logger_t *l);
+                                 jk_ws_service_t *s, jk_log_context_t *l);
 
 /*
  * Return values of service() method for ajp12 worker:
@@ -99,7 +99,7 @@ static int ajpv12_handle_request(ajp12_endpoint_t * p,
  */
 static int JK_METHOD service(jk_endpoint_t *e,
                              jk_ws_service_t *s,
-                             jk_logger_t *l, int *is_error)
+                             jk_log_context_t *l, int *is_error)
 {
     ajp12_endpoint_t *p;
     unsigned int attempt;
@@ -157,7 +157,7 @@ static int JK_METHOD service(jk_endpoint_t *e,
     return JK_FALSE;
 }
 
-static int JK_METHOD done(jk_endpoint_t **e, jk_logger_t *l)
+static int JK_METHOD done(jk_endpoint_t **e, jk_log_context_t *l)
 {
     jk_log(l, JK_LOG_DEBUG, "Into jk_endpoint_t::done");
     if (e && *e && (*e)->endpoint_private) {
@@ -176,7 +176,7 @@ static int JK_METHOD done(jk_endpoint_t **e, jk_logger_t *l)
 
 static int JK_METHOD validate(jk_worker_t *pThis,
                               jk_map_t *props,
-                              jk_worker_env_t *we, jk_logger_t *l)
+                              jk_worker_env_t *we, jk_log_context_t *l)
 {
     jk_log(l, JK_LOG_DEBUG, "Into jk_worker_t::validate");
 
@@ -199,23 +199,26 @@ static int JK_METHOD validate(jk_worker_t *pThis,
                p->name, host, port);
 
         if (host) {
-            if (!jk_resolve(host, port, &p->worker_inet_addr, we->pool, JK_FALSE, l)) {
+            if (!jk_resolve(host, port, &p->worker_inet_addr, we->pool,
+                            JK_FALSE, l)) {
                 jk_log(l, JK_LOG_ERROR,
                        "In jk_worker_t::validate, host '%s:%d' resolve failed",
                        host, port);
                 return JK_FALSE;
             }
-        } else {
+        }
+        else {
             jk_log(l, JK_LOG_ERROR,
                    "In jk_worker_t::validate, Error no host name given");
             return JK_FALSE;
         }
         if (source && *source) {
-            if (!jk_resolve(source, 0, &p->worker_source_inet_addr, we->pool, JK_FALSE, l)) {
+            if (!jk_resolve(source, 0, &p->worker_source_inet_addr, we->pool,
+                            JK_FALSE, l)) {
                 p->worker_source_inet_addr.ipaddr_ptr = NULL;
                 jk_log(l, JK_LOG_WARNING,
-                       "In jk_worker_t::validate, source addr '%s' resolve failed - ignored",
-                       source);
+                       "In jk_worker_t::validate, source addr '%s' resolve failed"
+                       " - ignored", source);
             }
         }
         return JK_TRUE;
@@ -230,14 +233,14 @@ static int JK_METHOD validate(jk_worker_t *pThis,
 
 static int JK_METHOD init(jk_worker_t *pThis,
                           jk_map_t *props,
-                          jk_worker_env_t *we, jk_logger_t *log)
+                          jk_worker_env_t *we, jk_log_context_t *l)
 {
     /* Nothing to do for now */
     return JK_TRUE;
 }
 
 static int JK_METHOD get_endpoint(jk_worker_t *pThis,
-                                  jk_endpoint_t **pend, jk_logger_t *l)
+                                  jk_endpoint_t **pend, jk_log_context_t *l)
 {
     jk_log(l, JK_LOG_DEBUG, "Into jk_worker_t::get_endpoint");
 
@@ -264,7 +267,7 @@ static int JK_METHOD get_endpoint(jk_worker_t *pThis,
     return JK_FALSE;
 }
 
-static int JK_METHOD destroy(jk_worker_t **pThis, jk_logger_t *l)
+static int JK_METHOD destroy(jk_worker_t **pThis, jk_log_context_t *l)
 {
     jk_log(l, JK_LOG_DEBUG, "Into jk_worker_t::destroy");
     if (pThis && *pThis && (*pThis)->worker_private) {
@@ -280,7 +283,7 @@ static int JK_METHOD destroy(jk_worker_t **pThis, jk_logger_t *l)
 }
 
 int JK_METHOD ajp12_worker_factory(jk_worker_t **w,
-                                   const char *name, jk_logger_t *l)
+                                   const char *name, jk_log_context_t *l)
 {
     jk_log(l, JK_LOG_DEBUG, "Into ajp12_worker_factory");
     if (NULL != name && NULL != w) {
@@ -398,7 +401,7 @@ static int ajpv12_flush(ajp12_endpoint_t * p)
 }
 
 static int ajpv12_handle_request(ajp12_endpoint_t * p,
-                                 jk_ws_service_t *s, jk_logger_t *l)
+                                 jk_ws_service_t *s, jk_log_context_t *l)
 {
     int ret;
 
@@ -409,9 +412,12 @@ static int ajpv12_handle_request(ajp12_endpoint_t * p,
     jk_log(l, JK_LOG_DEBUG,
            "ajpv12_handle_request, sending the ajp12 start sequence");
 
-    ret = (ajpv12_mark(p, 1) && ajpv12_sendstring(p, s->method) && ajpv12_sendstring(p, 0) &&   /* zone */
+    ret = (ajpv12_mark(p, 1) &&
+           ajpv12_sendstring(p, s->method) &&
+           ajpv12_sendstring(p, 0) &&   /* zone */
            ajpv12_sendstring(p, 0) &&   /* servlet */
-           ajpv12_sendstring(p, s->server_name) && ajpv12_sendstring(p, 0) &&   /* doc root */
+           ajpv12_sendstring(p, s->server_name) &&
+           ajpv12_sendstring(p, 0) &&   /* doc root */
            ajpv12_sendstring(p, 0) &&   /* path info */
            ajpv12_sendstring(p, 0) &&   /* path translated */
 #if defined(AS400) && !defined(AS400_UTF8)
@@ -429,21 +435,26 @@ static int ajpv12_handle_request(ajp12_endpoint_t * p,
 #else
            ajpv12_sendstring(p, s->method) &&
 #endif
-           ajpv12_sendstring(p, s->req_uri) && ajpv12_sendstring(p, 0) &&       /* */
+           ajpv12_sendstring(p, s->req_uri) &&
+           ajpv12_sendstring(p, 0) &&
            ajpv12_sendstring(p, 0) &&   /* SCRIPT_NAME */
 #if defined(AS400) && !defined(AS400_UTF8)
            ajpv12_sendasciistring(p, s->server_name) &&
 #else
            ajpv12_sendstring(p, s->server_name) &&
 #endif
-           ajpv12_sendint(p, s->server_port) && ajpv12_sendstring(p, s->protocol) && ajpv12_sendstring(p, 0) && /* SERVER_SIGNATURE */
-           ajpv12_sendstring(p, s->server_software) && ajpv12_sendstring(p, s->route) &&    /* JSERV_ROUTE */
+           ajpv12_sendint(p, s->server_port) &&
+           ajpv12_sendstring(p, s->protocol) &&
+           ajpv12_sendstring(p, 0) && /* SERVER_SIGNATURE */
+           ajpv12_sendstring(p, s->server_software) &&
+           ajpv12_sendstring(p, s->route) &&    /* JSERV_ROUTE */
            ajpv12_sendstring(p, "") &&  /* JSERV ajpv12 compatibility */
            ajpv12_sendstring(p, ""));   /* JSERV ajpv12 compatibility */
 
     if (!ret) {
         jk_log(l, JK_LOG_ERROR,
-               "In ajpv12_handle_request, failed to send the ajp12 start sequence");
+               "In ajpv12_handle_request, "
+               "failed to send the ajp12 start sequence");
         return JK_FALSE;
     }
 
@@ -511,7 +522,8 @@ static int ajpv12_handle_request(ajp12_endpoint_t * p,
 
             if (!s->read(s, buf, to_read, &this_time)) {
                 jk_log(l, JK_LOG_ERROR,
-                       "In ajpv12_handle_request, failed to read from the web server");
+                       "In ajpv12_handle_request, "
+                       "failed to read from the web server");
                 return JK_FALSE;
             }
             jk_log(l, JK_LOG_DEBUG, "ajpv12_handle_request, read %d bytes",
@@ -520,7 +532,8 @@ static int ajpv12_handle_request(ajp12_endpoint_t * p,
                 so_far += this_time;
                 if ((int)this_time != send(p->sd, buf, this_time, 0)) {
                     jk_log(l, JK_LOG_ERROR,
-                           "In ajpv12_handle_request, failed to write to the container");
+                           "In ajpv12_handle_request, "
+                           "failed to write to the container");
                     return JK_FALSE;
                 }
                 jk_log(l, JK_LOG_DEBUG,
@@ -528,7 +541,9 @@ static int ajpv12_handle_request(ajp12_endpoint_t * p,
             }
             else if (this_time == 0) {
                 jk_log(l, JK_LOG_ERROR,
-                       "In ajpv12_handle_request, Error: short read. content length is %" JK_UINT64_T_FMT ", read %" JK_UINT64_T_FMT,
+                       "In ajpv12_handle_request, Error: short read. "
+                       "Content length is %" JK_UINT64_T_FMT
+                       ", read %" JK_UINT64_T_FMT,
                        s->content_length, so_far);
                 return JK_FALSE;
             }
@@ -540,7 +555,7 @@ static int ajpv12_handle_request(ajp12_endpoint_t * p,
 }
 
 static int ajpv12_handle_response(ajp12_endpoint_t * p,
-                                  jk_ws_service_t *s, jk_logger_t *l)
+                                  jk_ws_service_t *s, jk_log_context_t *l)
 {
     int status = 200;
     char *reason = NULL;
