@@ -118,7 +118,7 @@ extern "C"
  */
 
 int ajp13_marshal_shutdown_into_msgb(jk_msg_buf_t *msg,
-                                     jk_pool_t *p, jk_logger_t *l);
+                                     jk_pool_t *p, jk_log_context_t *log_ctx);
 
 #ifdef __cplusplus
 }
