@@ -31,7 +31,7 @@
  * Compute the MD5 with ENTROPY / SECRET KEY
  */
 
-void ajp14_compute_md5(jk_login_service_t *s, jk_logger_t *l)
+void ajp14_compute_md5(jk_login_service_t *s, jk_log_context_t *l)
 {
     JK_TRACE_ENTER(l);
     jk_md5((const unsigned char *)s->entropy,
@@ -54,7 +54,8 @@ void ajp14_compute_md5(jk_login_service_t *s, jk_logger_t *l)
  */
 
 int ajp14_marshal_login_init_into_msgb(jk_msg_buf_t *msg,
-                                       jk_login_service_t *s, jk_logger_t *l)
+                                       jk_login_service_t *s,
+                                       jk_log_context_t *l)
 {
     JK_TRACE_ENTER(l);
     /* To be on the safe side */
@@ -99,7 +100,7 @@ int ajp14_marshal_login_init_into_msgb(jk_msg_buf_t *msg,
  */
 
 int ajp14_unmarshal_login_seed(jk_msg_buf_t *msg,
-                               jk_login_service_t *s, jk_logger_t *l)
+                               jk_login_service_t *s, jk_log_context_t *l)
 {
     JK_TRACE_ENTER(l);
 
@@ -126,7 +127,8 @@ int ajp14_unmarshal_login_seed(jk_msg_buf_t *msg,
  */
 
 int ajp14_marshal_login_comp_into_msgb(jk_msg_buf_t *msg,
-                                       jk_login_service_t *s, jk_logger_t *l)
+                                       jk_login_service_t *s,
+                                       jk_log_context_t *l)
 {
     JK_TRACE_ENTER(l);
 
@@ -167,7 +169,7 @@ int ajp14_marshal_login_comp_into_msgb(jk_msg_buf_t *msg,
  */
 
 int ajp14_unmarshal_log_ok(jk_msg_buf_t *msg,
-                           jk_login_service_t *s, jk_logger_t *l)
+                           jk_login_service_t *s, jk_log_context_t *l)
 {
     unsigned long nego;
     char *sname;
@@ -192,7 +194,8 @@ int ajp14_unmarshal_log_ok(jk_msg_buf_t *msg,
         return JK_FALSE;
     }
 
-    if (s->servlet_engine_name) /* take care of removing previously allocated data */
+    /* take care of removing previously allocated data */
+    if (s->servlet_engine_name)
         free(s->servlet_engine_name);
 
     s->servlet_engine_name = strdup(sname);
@@ -218,7 +221,7 @@ int ajp14_unmarshal_log_ok(jk_msg_buf_t *msg,
  *
  */
 
-int ajp14_unmarshal_log_nok(jk_msg_buf_t *msg, jk_logger_t *l)
+int ajp14_unmarshal_log_nok(jk_msg_buf_t *msg, jk_log_context_t *l)
 {
     unsigned long status;
 
@@ -250,7 +253,8 @@ int ajp14_unmarshal_log_nok(jk_msg_buf_t *msg, jk_logger_t *l)
  */
 
 int ajp14_marshal_shutdown_into_msgb(jk_msg_buf_t *msg,
-                                     jk_login_service_t *s, jk_logger_t *l)
+                                     jk_login_service_t *s,
+                                     jk_log_context_t *l)
 {
 
     JK_TRACE_ENTER(l);
@@ -289,7 +293,7 @@ int ajp14_marshal_shutdown_into_msgb(jk_msg_buf_t *msg,
  * +----------------------+-----------------------+
  *
  */
-int ajp14_unmarshal_shutdown_nok(jk_msg_buf_t *msg, jk_logger_t *l)
+int ajp14_unmarshal_shutdown_nok(jk_msg_buf_t *msg, jk_log_context_t *l)
 {
     unsigned long status;
 
@@ -319,7 +323,8 @@ int ajp14_unmarshal_shutdown_nok(jk_msg_buf_t *msg, jk_logger_t *l)
  */
 
 int ajp14_marshal_unknown_packet_into_msgb(jk_msg_buf_t *msg,
-                                           jk_msg_buf_t *unk, jk_logger_t *l)
+                                           jk_msg_buf_t *unk,
+                                           jk_log_context_t *l)
 {
     JK_TRACE_ENTER(l);
 
@@ -341,8 +346,8 @@ int ajp14_marshal_unknown_packet_into_msgb(jk_msg_buf_t *msg,
         return JK_FALSE;
     }
     /*
-     * UNHANDLED MESSAGE (Question : Did we have to send all the message or only part of)
-     *                                       (           ie: only 1k max                                                                )
+     * UNHANDLED MESSAGE (Question : Did we have to send all the message
+     * or only part of) (ie: only 1k max)
      */
     if (jk_b_append_bytes(msg, unk->buf, unk->len)) {
         jk_log(l, JK_LOG_ERROR,
@@ -365,7 +370,7 @@ int ajp14_marshal_unknown_packet_into_msgb(jk_msg_buf_t *msg,
  */
 
 int ajp14_marshal_context_query_into_msgb(jk_msg_buf_t *msg,
-                                          char *virtual, jk_logger_t *l)
+                                          char *virtual, jk_log_context_t *l)
 {
     JK_TRACE_ENTER(l);
 
@@ -406,7 +411,7 @@ int ajp14_marshal_context_query_into_msgb(jk_msg_buf_t *msg,
  */
 
 int ajp14_unmarshal_context_info(jk_msg_buf_t *msg,
-                                 jk_context_t *c, jk_logger_t *l)
+                                 jk_context_t *c, jk_log_context_t *l)
 {
     char *vname;
     char *cname;
@@ -505,7 +510,8 @@ int ajp14_unmarshal_context_info(jk_msg_buf_t *msg,
 /*
  * Build the Context State Query Cmd
  *
- * We send the list of contexts where we want to know state, empty string end context list*
+ * We send the list of contexts where we want to know state,
+ * empty string ends context list
  * If cname is set, only ask about THIS context
  *
  * +----------------------------+----------------------------------+----------------------------+----+
@@ -516,7 +522,7 @@ int ajp14_unmarshal_context_info(jk_msg_buf_t *msg,
 
 int ajp14_marshal_context_state_into_msgb(jk_msg_buf_t *msg,
                                           jk_context_t *c,
-                                          char *cname, jk_logger_t *l)
+                                          char *cname, jk_log_context_t *l)
 {
     jk_context_item_t *ci;
     int i;
@@ -610,7 +616,7 @@ int ajp14_marshal_context_state_into_msgb(jk_msg_buf_t *msg,
  */
 
 int ajp14_unmarshal_context_state_reply(jk_msg_buf_t *msg,
-                                        jk_context_t *c, jk_logger_t *l)
+                                        jk_context_t *c, jk_log_context_t *l)
 {
     char *vname;
     char *cname;
@@ -683,7 +689,7 @@ int ajp14_unmarshal_context_state_reply(jk_msg_buf_t *msg,
  */
 
 int ajp14_unmarshal_context_update_cmd(jk_msg_buf_t *msg,
-                                       jk_context_t *c, jk_logger_t *l)
+                                       jk_context_t *c, jk_log_context_t *l)
 {
     int rc;
     JK_TRACE_ENTER(l);
