@@ -42,7 +42,7 @@ extern "C"
 #define JK_AJP14_WORKER_TYPE (3)
 
 int JK_METHOD ajp14_worker_factory(jk_worker_t **w,
-                                   const char *name, jk_logger_t *l);
+                                   const char *name, jk_log_context_t *log_ctx);
 
 #ifdef __cplusplus
 }
