@@ -40,28 +40,28 @@ extern "C"
 void jk_clone_sockaddr(jk_sockaddr_t *out, jk_sockaddr_t *in);
 
 int jk_resolve(const char *host, int port, jk_sockaddr_t *rc, void *pool,
-               int prefer_ipv6, jk_logger_t *l);
+               int prefer_ipv6, jk_log_context_t *log_ctx);
 
 jk_sock_t jk_open_socket(jk_sockaddr_t *addr, jk_sockaddr_t *source,
                          int keepalive,
                          int timeout, int connect_timeout,
-                         int sock_buf, jk_logger_t *l);
+                         int sock_buf, jk_log_context_t *log_ctx);
 
-int jk_close_socket(jk_sock_t sd, jk_logger_t *l);
+int jk_close_socket(jk_sock_t sd, jk_log_context_t *log_ctx);
 
-int jk_shutdown_socket(jk_sock_t sd, jk_logger_t *l);
+int jk_shutdown_socket(jk_sock_t sd, jk_log_context_t *log_ctx);
 
-int jk_tcp_socket_sendfull(jk_sock_t sd, const unsigned char *b, int len, jk_logger_t *l);
+int jk_tcp_socket_sendfull(jk_sock_t sd, const unsigned char *b, int len, jk_log_context_t *log_ctx);
 
-int jk_tcp_socket_recvfull(jk_sock_t sd, unsigned char *b, int len, jk_logger_t *l);
+int jk_tcp_socket_recvfull(jk_sock_t sd, unsigned char *b, int len, jk_log_context_t *log_ctx);
 
 char *jk_dump_hinfo(jk_sockaddr_t *saddr, char *buf, size_t size);
 
 char *jk_dump_sinfo(jk_sock_t sd, char *buf, size_t size);
 
-int jk_is_input_event(jk_sock_t sd, int timeout, jk_logger_t *l);
+int jk_is_input_event(jk_sock_t sd, int timeout, jk_log_context_t *log_ctx);
 
-int jk_is_socket_connected(jk_sock_t sd, jk_logger_t *l);
+int jk_is_socket_connected(jk_sock_t sd, jk_log_context_t *log_ctx);
 
 
 /***
