@@ -19,7 +19,6 @@
  * Description: load balance worker header file                            *
  * Author:      Gal Shachor <shachor@il.ibm.com>                           *
  * Author:      Rainer Jung <rjung@apache.org>                             *
- * Version:     $Revision: 1838830 $                                           *
  ***************************************************************************/
 
 #ifndef JK_LB_WORKER_H
@@ -62,7 +61,7 @@ extern "C"
 #define JK_LB_LOCK_TEXT_DEF            (JK_LB_LOCK_TEXT_OPTIMISTIC)
 /*
  * The following definitions for state and activation
- * need to be kept in sync with the two macros 
+ * need to be kept in sync with the two macros
  * JK_WORKER_USABLE() and JK_WORKER_USABLE_STICKY() in jk_lb_worker.c.
  * Since we use ordered comparisons there instead of multiple
  * equal/unequal compares, order of the values is critical here.
@@ -137,18 +136,18 @@ struct lb_sub_worker
     /* Shared memory worker data */
     jk_shm_lb_sub_worker_t *s;
 
-    char         name[JK_SHM_STR_SIZ];
+    shm_str      name;
     /* Sequence counter starting at 0 and increasing
      * every time we change the config
      */
     volatile unsigned int sequence;
 
     /* route */
-    char    route[JK_SHM_STR_SIZ];
+    shm_str route;
     /* worker domain */
-    char    domain[JK_SHM_STR_SIZ];
+    shm_str domain;
     /* worker redirect route */
-    char    redirect[JK_SHM_STR_SIZ];
+    shm_str redirect;
     /* worker distance */
     int distance;
     /* current activation state (config) of the worker */
@@ -168,7 +167,7 @@ struct lb_worker
     /* Shared memory worker data */
     jk_shm_lb_worker_t *s;
 
-    char         name[JK_SHM_STR_SIZ];
+    shm_str      name;
     /* Sequence counter starting at 0 and increasing
      * every time we change the config
      */
@@ -195,33 +194,34 @@ struct lb_worker
     unsigned int max_packet_size;
     unsigned int next_offset;
     /* Session cookie */
-    char         session_cookie[JK_SHM_STR_SIZ];
+    shm_str      session_cookie;
     /* Session path */
-    char         session_path[JK_SHM_STR_SIZ];
+    shm_str      session_path;
     int          set_session_cookie;
-    char         session_cookie_path[JK_SHM_STR_SIZ];
+    shm_str      session_cookie_path;
 };
 typedef struct lb_worker lb_worker_t;
 
 int JK_METHOD lb_worker_factory(jk_worker_t **w,
-                                const char *name, jk_logger_t *l);
+                                const char *name, jk_log_context_t *log_ctx);
 
-const char *jk_lb_get_lock_direct(int lblock, jk_logger_t *l);
-const char *jk_lb_get_lock(lb_worker_t *p, jk_logger_t *l);
+const char *jk_lb_get_lock_direct(int lblock, jk_log_context_t *log_ctx);
+const char *jk_lb_get_lock(lb_worker_t *p, jk_log_context_t *log_ctx);
 int jk_lb_get_lock_code(const char *v);
-const char *jk_lb_get_method_direct(int lbmethod, jk_logger_t *l);
-const char *jk_lb_get_method(lb_worker_t *p, jk_logger_t *l);
+const char *jk_lb_get_method_direct(int lbmethod, jk_log_context_t *log_ctx);
+const char *jk_lb_get_method(lb_worker_t *p, jk_log_context_t *log_ctx);
 int jk_lb_get_method_code(const char *v);
-const char *jk_lb_get_state_direct(int state, jk_logger_t *l);
-const char *jk_lb_get_state(lb_sub_worker_t *p, jk_logger_t *l);
+const char *jk_lb_get_state_direct(int state, jk_log_context_t *log_ctx);
+const char *jk_lb_get_state(lb_sub_worker_t *p, jk_log_context_t *log_ctx);
 int jk_lb_get_state_code(const char *v);
-const char *jk_lb_get_activation_direct(int activation, jk_logger_t *l);
-const char *jk_lb_get_activation(lb_sub_worker_t *p, jk_logger_t *l);
+const char *jk_lb_get_activation_direct(int activation, jk_log_context_t *log_ctx);
+const char *jk_lb_get_activation(lb_sub_worker_t *p, jk_log_context_t *log_ctx);
 int jk_lb_get_activation_code(const char *v);
-void reset_lb_values(lb_worker_t *p, jk_logger_t *l);
-void jk_lb_pull(lb_worker_t * p, int locked, jk_logger_t *l);
-void jk_lb_push(lb_worker_t * p, int locked, int push_all_members, jk_logger_t *l);
-void update_mult(lb_worker_t * p, jk_logger_t *l);
+void reset_lb_values(lb_worker_t *p, jk_log_context_t *log_ctx);
+void jk_lb_pull(lb_worker_t * p, int locked, jk_log_context_t *log_ctx);
+void jk_lb_push(lb_worker_t * p, int locked, int push_all_members,
+                jk_log_context_t *log_ctx);
+void update_mult(lb_worker_t * p, jk_log_context_t *log_ctx);
 
 #ifdef __cplusplus
 }
