@@ -51,7 +51,10 @@ extern "C"
 #define JK_SHM_DEF_WORKERS        64
 #define JK_SHM_ALIGNMENT          JK_SHM_SLOT_SIZE
 #define JK_SHM_ALIGN(x)           JK_ALIGN((x), JK_SHM_ALIGNMENT)
-#define JK_SHM_MIN_SIZE           ((JK_SHM_SLOT_SIZE * JK_SHM_DEF_WORKERS * 3) + JK_SHM_ALIGNMENT)
+#define JK_SHM_MIN_SIZE           ((JK_SHM_SLOT_SIZE * JK_SHM_DEF_WORKERS * 3) + \
+                                   JK_SHM_ALIGNMENT)
+
+typedef char shm_str[JK_SHM_STR_SIZ];
 
 /** jk shm generic worker record structure */
 struct jk_shm_worker_header
@@ -61,7 +64,7 @@ struct jk_shm_worker_header
     /* JK_XXX_WORKER_TYPE */
     int     type;
     /* worker name */
-    char    name[JK_SHM_STR_SIZ];
+    shm_str name;
     /* parent slot id.
      * Zero in case worker does not belong to balancer.
      */
@@ -77,7 +80,7 @@ typedef struct jk_shm_worker_header jk_shm_worker_header_t;
 struct jk_shm_ajp_worker
 {
     jk_shm_worker_header_t h;
-    char host[JK_SHM_STR_SIZ];
+    shm_str host;
     int port;
     volatile int addr_sequence;
 
@@ -130,11 +133,11 @@ struct jk_shm_lb_sub_worker
     jk_shm_worker_header_t h;
 
     /* route */
-    char    route[JK_SHM_STR_SIZ];
+    shm_str route;
     /* worker domain */
-    char    domain[JK_SHM_STR_SIZ];
+    shm_str domain;
     /* worker redirect route */
-    char    redirect[JK_SHM_STR_SIZ];
+    shm_str redirect;
     /* worker distance */
     volatile int distance;
     /* current activation state (config) of the worker */
@@ -185,42 +188,51 @@ struct jk_shm_lb_worker
 };
 typedef struct jk_shm_lb_worker jk_shm_lb_worker_t;
 
+int jk_shm_str_init(shm_str dst, const char *src,
+                    const char *name, jk_log_context_t *l);
+
+int jk_shm_str_init_ne(shm_str dst, const char *src,
+                       const char *name, jk_log_context_t *l);
+
+void jk_shm_str_copy(shm_str dst, shm_str src,
+                     jk_log_context_t *l);
+
 const char *jk_shm_name(void);
 
 /* Calculate needed shm size */
-int jk_shm_calculate_size(jk_map_t *init_data, jk_logger_t *l);
+int jk_shm_calculate_size(jk_map_t *init_data, jk_log_context_t *log_ctx);
 
 /* Open the shared memory creating file if needed
  */
-int jk_shm_open(const char *fname, int sz, jk_logger_t *l);
+int jk_shm_open(const char *fname, int sz, jk_log_context_t *log_ctx);
 
 /* Close the shared memory
  */
-void jk_shm_close(jk_logger_t *l);
+void jk_shm_close(jk_log_context_t *log_ctx);
 
 /* Attach the shared memory in child process.
  * File has to be opened in parent.
  */
-int jk_shm_attach(const char *fname, int sz, jk_logger_t *l);
+int jk_shm_attach(const char *fname, int sz, jk_log_context_t *log_ctx);
 
 /* allocate shm ajp worker record
  * If there is no shm present the pool will be used instead
  */
 jk_shm_ajp_worker_t *jk_shm_alloc_ajp_worker(jk_pool_t *p, const char *name,
-                                             jk_logger_t *l);
+                                             jk_log_context_t *log_ctx);
 
 /* allocate shm lb sub worker record
  * If there is no shm present the pool will be used instead
  */
 jk_shm_lb_sub_worker_t *jk_shm_alloc_lb_sub_worker(jk_pool_t *p,
                                                    int lb_id, const char *name,
-                                                   jk_logger_t *l);
+                                                   jk_log_context_t *log_ctx);
 
 /* allocate shm lb worker record
  * If there is no shm present the pool will be used instead
  */
 jk_shm_lb_worker_t *jk_shm_alloc_lb_worker(jk_pool_t *p, const char *name,
-                                           jk_logger_t *l);
+                                           jk_log_context_t *log_ctx);
 
 int jk_shm_check_maintain(time_t trigger);
 
