@@ -446,19 +446,19 @@ void jk_set_time_fmt(jk_logger_t *l, const char *jk_log_fmt)
             if (offset + len < JK_TIME_MAX_SIZE) {
                 l->log_fmt_type = JK_TIME_SUBSEC_MILLI;
                 l->log_fmt_offset = offset;
-                strncpy(l->log_fmt_subsec, jk_log_fmt, offset);
-                strncpy(l->log_fmt_subsec + offset, JK_TIME_PATTERN_MILLI, len);
-                strncpy(l->log_fmt_subsec + offset + len,
-                        s + strlen(JK_TIME_CONV_MILLI),
-                        JK_TIME_MAX_SIZE - offset - len - 1);
+                memcpy(l->log_fmt_subsec, jk_log_fmt, offset);
+                memcpy(l->log_fmt_subsec + offset, JK_TIME_PATTERN_MILLI, len);
+                memcpy(l->log_fmt_subsec + offset + len,
+                       s + strlen(JK_TIME_CONV_MILLI),
+                       JK_TIME_MAX_SIZE - offset - len - 1);
                 /* Now we put a stop mark into the string to make it's length
                  * at most JK_TIME_MAX_SIZE-1 plus terminating '\0'.
                  */
-                l->log_fmt_subsec[JK_TIME_MAX_SIZE-1] = '\0';
+                l->log_fmt_subsec[JK_TIME_MAX_SIZE - 1] = '\0';
                 l->log_fmt_size = strlen(l->log_fmt_subsec);
             }
-            /* Look for the first occurence of JK_TIME_CONV_MICRO */
         }
+        /* Look for the first occurence of JK_TIME_CONV_MICRO */
         else if ((s = strstr(jk_log_fmt, JK_TIME_CONV_MICRO))) {
             size_t offset = s - jk_log_fmt;
             size_t len = strlen(JK_TIME_PATTERN_MICRO);
@@ -471,20 +471,18 @@ void jk_set_time_fmt(jk_logger_t *l, const char *jk_log_fmt)
             if (offset + len < JK_TIME_MAX_SIZE) {
                 l->log_fmt_type = JK_TIME_SUBSEC_MICRO;
                 l->log_fmt_offset = offset;
-                strncpy(l->log_fmt_subsec, jk_log_fmt, offset);
-                strncpy(l->log_fmt_subsec + offset, JK_TIME_PATTERN_MICRO, len);
-                strncpy(l->log_fmt_subsec + offset + len,
-                        s + strlen(JK_TIME_CONV_MICRO),
-                        JK_TIME_MAX_SIZE - offset - len - 1);
+                memcpy(l->log_fmt_subsec, jk_log_fmt, offset);
+                memcpy(l->log_fmt_subsec + offset, JK_TIME_PATTERN_MICRO, len);
+                memcpy(l->log_fmt_subsec + offset + len,
+                       s + strlen(JK_TIME_CONV_MICRO),
+                       JK_TIME_MAX_SIZE - offset - len - 1);
                 /* Now we put a stop mark into the string to make it's length
                  * at most JK_TIME_MAX_SIZE-1 plus terminating '\0'.
                  */
-                l->log_fmt_subsec[JK_TIME_MAX_SIZE-1] = '\0';
+                l->log_fmt_subsec[JK_TIME_MAX_SIZE - 1] = '\0';
                 l->log_fmt_size = strlen(l->log_fmt_subsec);
             }
         }
-        jk_log(l, JK_LOG_DEBUG, "Pre-processed log time stamp format is '%s'",
-               l->log_fmt_type == JK_TIME_SUBSEC_NONE ? l->log_fmt : l->log_fmt_subsec);
     }
 }
 
@@ -510,7 +508,7 @@ static int set_time_str(char *str, int len, jk_logger_t *l)
     log_fmt[0] = '\0';
 
 #ifndef NO_GETTIMEOFDAY
-    if ( l->log_fmt_type != JK_TIME_SUBSEC_NONE ) {
+    if (l->log_fmt_type != JK_TIME_SUBSEC_NONE) {
         struct timeval tv;
         int rc = 0;
 
@@ -694,11 +692,12 @@ int jk_close_file_logger(jk_logger_t **l)
     return JK_FALSE;
 }
 
-int jk_log(jk_logger_t *l,
+int jk_log(jk_log_context_t *log_ctx,
            const char *file, int line, const char *funcname, int level,
            const char *fmt, ...)
 {
     int rc = 0;
+    jk_logger_t *l;
 
     /*
      * Need to reserve space for terminating zero byte
@@ -706,7 +705,7 @@ int jk_log(jk_logger_t *l,
      * to the output routing.
      */
     static int usable_size = LOG_BUFFER_SIZE - 3;
-    if (!l || !file || !fmt) {
+    if (!log_ctx || !(l = log_ctx->logger) || !file || !fmt) {
         return -1;
     }
 
@@ -726,6 +725,34 @@ int jk_log(jk_logger_t *l,
         used = set_time_str(buf, usable_size, l);
 
         if (line) { /* line==0 only used for request log item */
+            /* Log [requestid] for all levels except REQUEST.
+             */
+            const char *context_id;
+            if (log_ctx == NULL) {
+                context_id = "-";
+                rc = 1;
+            } else if (log_ctx->id == NULL) {
+                context_id = "NO-ID";
+                rc = 5;
+            }
+            else {
+                context_id = log_ctx->id;
+                rc = (int)strlen(context_id);
+            }
+            if (usable_size - used >= rc + 3) {
+                strncpy(buf + used, "[", 1);
+                used += 1;
+                strncpy(buf + used, context_id, rc);
+                used += rc;
+                strncpy(buf + used, "] ", 2);
+                used += 2;
+            }
+            else {
+                strcpy(buf, "Logging failed in context_id formatting");
+                l->log(l, level, (int)strlen(buf), buf);
+                return 0;
+            }
+
             /* Log [pid:threadid] for all levels except REQUEST.
              * This information helps to correlate lines from different logs.
              * Performance is no issue, because with production log levels
@@ -734,7 +761,7 @@ int jk_log(jk_logger_t *l,
             rc = snprintf(buf + used, usable_size - used,
                           "[%" JK_PID_T_FMT ":%" JK_PTHREAD_T_FMT "] ", getpid(), jk_gettid());
             used += rc;
-            if (rc < 0 ) {
+            if (rc < 0) {
                 strcpy(buf, "Logging failed in pid/tid formatting");
                 l->log(l, level, (int)strlen(buf), buf);
                 return 0;
@@ -808,20 +835,6 @@ int jk_log(jk_logger_t *l,
     return rc;
 }
 
-int jk_check_attribute_length(const char *name, const char *value,
-                              jk_logger_t *l)
-{
-    size_t len = strlen(value);
-    if (len > JK_MAX_NAME_LEN) {
-        jk_log(l, JK_LOG_ERROR,
-               "Worker %s '%s' is %d bytes too long, "
-               "a maximum of %d bytes is supported",
-               name, value, len - JK_MAX_NAME_LEN, JK_MAX_NAME_LEN);
-        return JK_FALSE;
-    }
-    return JK_TRUE;
-}
-
 const char *jk_get_worker_type(jk_map_t *m, const char *wname)
 {
     char buf[PARAM_BUFFER_SIZE];
@@ -2176,12 +2189,12 @@ int jk_wildchar_match(const char *str, const char *exp, int icase)
     return (str[x] != '\0');
 }
 
-int jk_servlet_normalize(char *path, jk_logger_t *logger)
+int jk_servlet_normalize(char *path, jk_log_context_t *log_ctx)
 {
     int l, w;
 
-    if (JK_IS_DEBUG_LEVEL(logger)) {
-        jk_log(logger, JK_LOG_DEBUG, "URI on entering jk_servlet_normalize: [%s]", path);
+    if (JK_IS_DEBUG_LEVEL(log_ctx)) {
+        jk_log(log_ctx, JK_LOG_DEBUG, "URI on entering jk_servlet_normalize: [%s]", path);
     }
 
     // This test allows the loops below to start at index 1 rather than 0.
@@ -2190,7 +2203,7 @@ int jk_servlet_normalize(char *path, jk_logger_t *logger)
             /* Most likely an "OPTIONS *" request */
             return 0;
         }
-        jk_log(logger, JK_LOG_WARNING, "Uri [%s] does not start with '/'.", path);
+        jk_log(log_ctx, JK_LOG_WARNING, "Uri [%s] does not start with '/'.", path);
         return JK_NORMALIZE_BAD_PATH;
     }
 
@@ -2252,10 +2265,10 @@ int jk_servlet_normalize(char *path, jk_logger_t *logger)
 
             // Wind w back to remove the previous segment
             if (w == 1) {
-                jk_log(logger,
-                        JK_LOG_EMERG,
-                        "[%s] contains a '/../' sequence that tries to escape above the root.",
-                        path);
+                jk_log(log_ctx,
+                       JK_LOG_EMERG,
+                       "[%s] contains a '/../' sequence that tries to escape above the root.",
+                       path);
                 return JK_NORMALIZE_TRAVERSAL;
             }
             do {
@@ -2274,14 +2287,14 @@ int jk_servlet_normalize(char *path, jk_logger_t *logger)
     }
     path[w] = '\0';
 
-    if (JK_IS_DEBUG_LEVEL(logger)) {
-        jk_log(logger, JK_LOG_DEBUG, "URI on exiting jk_servlet_normalize: [%s]", path);
+    if (JK_IS_DEBUG_LEVEL(log_ctx)) {
+        jk_log(log_ctx, JK_LOG_DEBUG, "URI on exiting jk_servlet_normalize: [%s]", path);
     }
 
     return 0;
 }
 
-int jk_strip_session_id(char* path, char* session_name, jk_logger_t *logger) {
+int jk_strip_session_id(char* path, char* session_name, jk_log_context_t *log_ctx) {
 
     char *jsessionid;
 
@@ -2289,9 +2302,9 @@ int jk_strip_session_id(char* path, char* session_name, jk_logger_t *logger) {
     if (jsessionid) {
         int i;
         int j;
-        if (JK_IS_DEBUG_LEVEL(logger)) {
-            jk_log(logger, JK_LOG_DEBUG,
-                    "removing session identifier for non servlet uri [%s]", path);
+        if (JK_IS_DEBUG_LEVEL(log_ctx)) {
+            jk_log(log_ctx, JK_LOG_DEBUG,
+                   "removing session identifier for non servlet uri [%s]", path);
         }
         // Found a session path parameter.
         // Need to skip at least as many characters as there are in
@@ -2309,9 +2322,9 @@ int jk_strip_session_id(char* path, char* session_name, jk_logger_t *logger) {
         // Terminate
         jsessionid[j] = '\0';
 
-        if (JK_IS_DEBUG_LEVEL(logger)) {
-            jk_log(logger, JK_LOG_DEBUG,
-                    "result of removing session identifier for non servlet uri is [%s]", path);
+        if (JK_IS_DEBUG_LEVEL(log_ctx)) {
+            jk_log(log_ctx, JK_LOG_DEBUG,
+                   "result of removing session identifier for non servlet uri is [%s]", path);
         }
         return 1;
     }
