@@ -53,7 +53,7 @@ usage() {
     echo "        -r: revision or hash to package, only allowed in"
     echo "            combination with '-b BRANCH', '-T' or '-d DIR'"
     echo "        -b: package from branch BRANCH"
-    echo "        -T: package from trunk/master"
+    echo "        -T: package from trunk/main"
     echo "        -d: package from local directory"
     echo "        -o: owner used for creating tar archive"
     echo "        -g: group used for creating tar archive"
@@ -175,10 +175,10 @@ if [ -n "$trunk" ]
 then
     if [ $USE_GIT -eq 1 ]
     then
-        JK_REV=`git ls-remote $REPOS refs/heads/master | awk '{print $1}'`
+        JK_REV=`git ls-remote $REPOS refs/heads/main | awk '{print $1}'`
         if [ -z "$JK_REV" ]
         then
-           echo "No git hash found via 'git ls-remote $REPOS refs/heads/master'"
+           echo "No git hash found via 'git ls-remote $REPOS refs/heads/main'"
            exit 3
         fi
         JK_SUFFIX=-${JK_REV}
@@ -362,7 +362,6 @@ copy_files ${JK_DIST}.tmp/jk/conf $JK_DIST/conf "$COPY_CONF"
 
 # Remove extra directories and files
 targetdir=${JK_DIST}
-rm -rf ${targetdir}/xdocs/jk2
 rm -f ${targetdir}/native/build.xml
 rm -f ${targetdir}/native/NOTICE
 rm -f ${targetdir}/native/LICENSE
@@ -376,10 +375,10 @@ cd ${JK_DIST}/native
 if [ $txtgen = y ]
 then
 # Check for links, elinks or w3m
-W3MOPTS="-dump -cols 80 -t 4 -S -O iso-8859-1 -T text/html"
-ELNKOPTS="-dump -dump-width 80 -dump-charset iso-8859-1 -no-numbering -no-home -no-references"
-LNKOPTS="-dump -width 80 -codepage iso-8859-1 -no-g -html-numbered-links 0"
-LYXOPTS="-dump -width=80 -nolist -nostatus -noprint -assume_local_charset=iso-8859-1"
+W3MOPTS="-dump -cols 80 -t 4 -S -O UTF-8 -T text/html"
+ELNKOPTS="-dump -dump-width 80 -dump-charset UTF-8 -no-numbering -no-home -no-references"
+LNKOPTS="-dump -width 80 -codepage UTF-8 -no-g -html-numbered-links 0"
+LYXOPTS="-dump -width=80 -nolist -nostatus -noprint -assume_local_charset=UTF-8"
 failed=true
 for tool in `echo "w3m elinks links lynx"`
 do
@@ -412,7 +411,7 @@ do
     esac
     rm -f CHANGES
     echo "Creating the CHANGES file using '$TOOL' ..."
-    ${TOOL} ../docs/miscellaneous/printer/changelog.html > CHANGES 2>/dev/null
+    ${TOOL} ../docs/miscellaneous/changelog.html | awk '/Preface/ {o=1} o>0' > CHANGES 2>/dev/null
     if [ -f CHANGES -a -s CHANGES ]
     then
       failed=false
@@ -432,9 +431,9 @@ rm -f NEWS
 touch NEWS
 for news in `ls -r ../xdocs/news/[0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9].xml`
 do
-  print=`echo $news | sed -e 's#xdocs/news#docs/news/printer#' -e 's#\.xml#.html#'`
+  print=`echo $news | sed -e 's#xdocs/news#docs/news#' -e 's#\.xml#.html#'`
   echo "Adding $print to NEWS file ..."
-  ${TOOL} $print >>NEWS
+  ${TOOL} $print | awk '/[0-9][0-9][0-9][0-9] News/ {o=1} o>0' >> NEWS
 done
 if [ ! -s NEWS ]
 then
